#
# spec file for package mbuffer
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2012 Pascal Bleser <pascal.bleser@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           mbuffer
Version:        20231216
Release:        1.4
Summary:        Replacement for "buffer" with many more Features
License:        GPL-3.0-or-later
Group:          Productivity/Text/Utilities
URL:            https://www.maier-komor.de/mbuffer.html
Source:         https://www.maier-komor.de/software/mbuffer/mbuffer-%{version}.tgz
BuildRequires:  libtool
BuildRequires:  openssl-devel

%description
mbuffer is a raplacement for buffer with additional functionality:
- display of I/O speed
- optional use of memory mapped I/O for huge buffers
- multithreaded instead of sharedmemory ipc
- multi volume support
- autoloader support
- networking support
- compatible command-line options

%prep
%setup -q

%build
%configure \
    --enable-md5 \
    --disable-debug

%make_build SHELL=/bin/sh

%install
install -D -m 0755 mbuffer "%{buildroot}%{_bindir}/mbuffer"
install -D -m 0644 mbuffer.1 "%{buildroot}%{_mandir}/man1/mbuffer.1"

%files
%license LICENSE
%doc AUTHORS ChangeLog NEWS README
%{_bindir}/mbuffer
%{_mandir}/man1/mbuffer.1%{?ext_man}

%changelog
* Fri May 24 2024 ming li <mli@suse.com>
- Update to version 20231216:
  * changed from `which` to `command` for Debian forward compatibility
* Mon May 29 2023 Dirk Müller <dmueller@suse.com>
- update to 20230301:
  * Fix breaking connections on WAN links: retry on EAGAIN
* Sun May 29 2022 Dirk Müller <dmueller@suse.com>
- update to 20220418:
  * fix handling of filesystem full on stdout
* Mon Jan 31 2022 Dirk Müller <dmueller@suse.com>
- update to 20211018:
  * fixes related to TCP timeout handling
  * enhancement: support setting config file via env var MBUFFERRC
  * documentation update
  * make TCPTimeout=0 disable the TCP timeout
  * changed default TCP timeout from 10s to 100s
  * TCP timeout now can be give with suffixes ms,s,min,h
  * documented option for TCP timeout
  * enhancement: accept IPv6 addresses in square bracket format
  * enhancement: more detailed warning message for connect failures
  * work around Solaris default old mercurial and incompatible sed
  * removed cancel after join for reader thread
  * updated install-sh
  * mbuffer.1 has outdated version tag
  * fix: hash algos should not suppress stdout
  * enhancement: added option --no-direct to disable use of O_DIRECT
  * defaults: raised default TCP timeout to 10ms for WAN connections
  * fix: leave TCP buffer size untouched if not set
  * enhancement: add option to set TCP timeout
  * performance optimization: use recv with MSG_WAITALL instead of read
  * configure fix: look for objdump also with target prefix
  * testing: make sure to use gtar for testing to avoid unexpected failures
  * portability: NetBSD compatibility fix
  * build enhancement: added dependency calculation for make
  * build enhancement: automatic version string generation
  * configure fix for some powerpc toolchains
  * update config.sub and config.guess
  * added option to perform direct I/Os on temporary file
  * autoadjust dependent parameters
  * human readable buffer size information instead of kiB
  * hashing infrastructure should also be enabled with libdl available
  * report input file name in message for open failure
  * fix: don't try to open network output as file after failure
  * fix: potential issue related to inet6 hosts handling
  * added complementary cmake based building and testing
  * some cleanup work
  * fix: erronous empty file generation on network connection failure
  * enhanced default settings for better performance
  * use O_DIRECT on input and output if possible
  * option --direct is now deprecated and has no effect
  * Output Size must be adjusted to Blocksize during initialization
  * man-page corrections
  * fixed some messages (typos and formatting)
  * fix for network initialization for systems without getaddrinfo
  * support suppressing messages with Verbose=silent and Verbose=none
  * fix detection of invalid arguments to option -v
  * Copyright update to 2019
  * consistently use CLOCK_MONOTONIC if available
  * handle time standing still or running backward
  * updated INSTALL file to reflect available options
  * added explanation for lack of MacOS support
  * linking of available hash libraries during runtime
* Tue Jun 12 2018 mvetter@suse.com
- Update to version 20180505 (important changes since 20151002):
  * fix potential hang with small input size
  * configure enhancement: objdump may be named gobjdump
  * fix tape end of file marker may be ignored
  * removed obsolete alpha code
  * fix: fix listen's backlog argument, which can cause issues on Linux 4.4
  * fix: fix potential assertion triggered by interrupted system call
  * fix: use thread-safe mt_usleep instead of sleep(3) for watchdog timing
  * enhancement: ignore EINTR for I/O syscalls
  * enhancement: report percent done, when input size is known (is a file)
  * enhancement: watchdog raises SIGKILL if SIGINT had no effect
  * added an example config file, with documentation of all options
  * added parameter StatusInterval
  * fix false warning on comments in config files
  * performance optimized defaults
  * fix: potential hang, when one output fails to open
- Remove mbuffer-fix_pointer_cast.patch: dont see a reason for this
* Tue Dec  1 2015 p.drouand@gmail.com
- Update to version 2015100 :
  * fix: SegV when argument to -v is missing
  * fix: potential infinite loop on output error
- Changes from version 20150412 :
  * fix: watchdog cannot do its job if it is cleaned up to early
  * fix: clear sa_flags and sa_mask before use, although ignored
- Changes from version 20141227 :
  * added option --pid to print PID of current process
  * updated usage to include option -W
  * man page formatting fixes
  * configure updates
  * support compiling on systems that do not define PATH_MAX
* Sat Jan 24 2015 andreas.stieger@gmx.de
- version 20141227:
  + added option --pid to print PID of current process
  + updated usage to include option -W
  + man page formatting fixes
  + configure updates
  + support compiling on systems that do not define PATH_MAX
* Wed Apr 16 2014 crrodriguez@opensuse.org
- version 20140310
  * added memory advise for buffer memory
  * prevent buffer overflow attack via defaults file
  * ignore defaults file from other users
  * updated documentation for use with cron
  * minor bugfixes
  * new feature: set option defaults in ~/.mbuffer.rc
  * enhancement: write status to the log file
  * enhancement: added option to suppress status logging
  * fix: formatting fix for summary message
- spec file changes:
  * refresh patch with p1
  * the mhash library is abandonware, this is no good
    since we are talking about crypto software, use openSSL instead.
* Mon Apr  8 2013 pascal.bleser@opensuse.org
- update to 20132020:
  * reverted incorrect fix for -P 100, which may lead to data corruption
  * reenable hash libraries (no correlation with data corruption)
  * bail out if any output fails to initialize
  * refixed hang on -P 100
  * reduced sending overhead
  * fixed handling of option -f
- changes from 20130209:
  * hash names should be compared case insensitive for convenience
  * safeguard against missing argument to option --hash
  * support for hash calculation withdrawn, due to potential data corruption,
    when the buffer runs full
* Sat Nov 17 2012 pascal.bleser@opensuse.org
- update to 20121111:
  * support float values as argument to memory options
  * added a watchdog that terminates mbuffer if input
    or output activity stalls (option -W)
* Sat May  5 2012 pascal.bleser@opensuse.org
- update to 20120505:
  * fix: suppress summary on stderr if -q is used with -l
  * fix: option -P 100 may lead to hang
* Sun Jul 24 2011 pascal.bleser@opensuse.org
- update to 20110724:
  * fix: garbage might be written after input error
  * enhancement: prompt for additional volumes for argument "-n 0"
  * enhancement: prompt for next volume on I/O error if -n is set (some tape
    devices incorrectly return -1/EIO instead of 0)
  * enhancement: added option to append to output file
  * update: remove use of deprecated interface sigignore
* Fri Mar 18 2011 pascal.bleser@opensuse.org
- update to 20110317:
  * an option was added to terminate on any kind of error
  * a hang when starting mbuffer in the background was fixed
  * the displayed dimensions were changed to be compliant to SI standards
* Thu Jan 20 2011 pascal.bleser@opensuse.org
- update to 20110119:
  * fixes an incorrect sanity check for the interaction between hashing and
    multiple outputs
* Thu Dec 30 2010 pascal.bleser@opensuse.org
- update to 20101230:
  * hash values now are also written to log files
  * this release will report the last block number on volume, report time per
    volume
* Fri May 28 2010 pascal.bleser@opensuse.org
- update to 20100526:
  * fixes an interaction between watermark and rate limitation algorithms that
    messed up rate limitation
  * fixes a potential deadlock on SIGINT
* Sat Mar 27 2010 pascal.bleser@opensuse.org
- update to 20100327:
  * a problem in which hash calculation was being omitted if no output file is
    specified was fixed
  * a summary is included in the log file in quiet mode
  * some typographical errors in the man page were fixed
* Mon Dec 28 2009 pascal.bleser@opensuse.org
- update to 20091227:
  * rate limitation now uses a monotonic time source if available
  * lockup on input error has been fixed
  * segfault in quiet mode has been fixed
  * cancellation fixes
* Sun Nov 22 2009 pascal.bleser@opensuse.org
- update to 20091122:
  * multiple fixes for assertion failures raised during error situations
* Tue Nov 10 2009 pascal.bleser@opensuse.org
- update to 20091110:
  * code is compiled for 64-bit word size by default, if that capability is
    available
  * a hang which occurred on SIGINT when input is idle was fixed
  * fixes were made for the IPv6 code
* Mon Oct 12 2009 pascal.bleser@opensuse.org
- update to 20091012:
  * adds a separate thread for hash calculation
  * adds support for libmhash with all provided hash algorithms
  * fixes a typo in the examples section
  * fixes a potential race condition
  * fixes a potential lockup on SIGINT
* Sun Jun 28 2009 pascal.bleser@opensuse.org
- update to 20090628:
  * adds support for IPv6 and service name lookup
  * reintegrates a lost fix for libmhash initialization
* Sat Feb 14 2009 guru@unixtech.be
- update to 20090215:
  * fixes a hang on transfer sizes smaller than blocksize with status display
    active
  * man page update, summary display update
  * libmhash initialization fix
  * termination latency with active status display is reduced
  * fix for -q suppressing the output of -H
* Wed Jan 14 2009 guru@unixtech.be
- update to 20090113:
  * a fix for an assertion failure in network mode when compiled for 64-bit
    architectures
* Tue Jan  6 2009 guru@unixtech.be
- scrapped old %%%%changelog entries
- update to 20090106
* Sun Dec  7 2008 guru@unixtech.be
- update to 20081207:
  * more intelligent TCP buffer tuning plus an undocumented option to manually
    set the TCP buffer size
  * fixes several typos, and fixes for some message formatting issues
* Sat Oct 25 2008 guru@unixtech.be
- update to 20081023:
  * mbuffer should not abort on SIGTERM
  * a segv which occurred when an invalid option was given was fixed
  * a minor codepath optimization was made
  * the status display now waits for the first block to be read
* Tue Oct 14 2008 guru@unixtech.be
- update to 20081015:
  * autoloader commands are now prevented from corrupting mbuffer's output
  * cancellation issues were fixed
  * sendfile should fall back to write
  * manpath needs to be created
  * support was added for O_DIRECT on systems that provide it
  * documentation updates
